import 'package:flutter/material.dart';

import 'package:minehunter/provider/data.dart';
import 'package:minehunter/ui/widgets/home/button_game_resume.dart';
import 'package:minehunter/ui/widgets/home/button_game_start_new.dart';

class Parameters extends StatelessWidget {
  const Parameters({super.key, required this.myProvider});

  final Data myProvider;

  static const double separatorHeight = 2.0;
  static const double blockMargin = 3.0;
  static const double blockPadding = 2.0;
  static const Color buttonBackgroundColor = Colors.white;
  static const Color buttonBorderColorActive = Colors.blue;
  static const Color buttonBorderColorInactive = Colors.white;
  static const double buttonBorderWidth = 10.0;
  static const double buttonBorderRadius = 8.0;
  static const double buttonPadding = 0.0;
  static const double buttonMargin = 0.0;

  @override
  Widget build(BuildContext context) {
    List<Widget> lines = [];

    final List<String> parameters = myProvider.availableParameters;
    for (int index = 0; index < parameters.length; index++) {
      lines.add(buildParameterSelector(myProvider, parameters[index]));
      lines.add(const SizedBox(height: separatorHeight));
    }

    myProvider.loadCurrentSavedState();
    Widget buttonsBlock = myProvider.hasCurrentSavedState()
        ? ResumeGameButton(myProvider: myProvider)
        : StartNewGameButton(myProvider: myProvider);

    return Column(
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: [
        const SizedBox(height: separatorHeight),
        Expanded(
          child: Column(
            mainAxisSize: MainAxisSize.min,
            mainAxisAlignment: MainAxisAlignment.center,
            children: lines,
          ),
        ),
        const SizedBox(height: separatorHeight),
        Container(
          child: buttonsBlock,
        ),
      ],
    );
  }

  static Image buildImageWidget(String imageAssetCode) {
    return Image(
      image: AssetImage('assets/icons/$imageAssetCode.png'),
      fit: BoxFit.fill,
    );
  }

  static Container buildImageContainerWidget(String imageAssetCode) {
    return Container(
      child: buildImageWidget(imageAssetCode),
    );
  }

  static Column buildDecorationImageWidget() {
    return Column(
      children: [
        TextButton(
          child: buildImageContainerWidget('placeholder'),
          onPressed: () {},
        ),
      ],
    );
  }

  Widget buildParameterSelector(Data myProvider, String parameterCode) {
    final List<String> availableValues = myProvider.getParameterAvailableValues(parameterCode);

    if (availableValues.length == 1) {
      return const SizedBox(height: 0.0);
    }

    return Table(
      defaultColumnWidth: const IntrinsicColumnWidth(),
      children: [
        TableRow(
          children: [
            for (int index = 0; index < availableValues.length; index++)
              Column(
                children: [
                  buildParameterButton(myProvider, parameterCode, availableValues[index])
                ],
              ),
          ],
        ),
      ],
    );
  }

  Widget buildParameterButton(Data myProvider, String parameterCode, String parameterValue) {
    final String currentValue = myProvider.getParameterValue(parameterCode).toString();

    final bool isActive = (parameterValue == currentValue);
    final String imageAsset = '${parameterCode}_$parameterValue';

    return TextButton(
      child: Container(
        margin: const EdgeInsets.all(buttonMargin),
        padding: const EdgeInsets.all(buttonPadding),
        decoration: BoxDecoration(
          color: buttonBackgroundColor,
          borderRadius: BorderRadius.circular(buttonBorderRadius),
          border: Border.all(
            color: isActive ? buttonBorderColorActive : buttonBorderColorInactive,
            width: buttonBorderWidth,
          ),
        ),
        child: buildImageWidget(imageAsset),
      ),
      onPressed: () => myProvider.setParameterValue(parameterCode, parameterValue),
    );
  }
}
