import 'package:flutter/material.dart';

import 'package:minehunter/provider/data.dart';
import 'package:minehunter/utils/board_utils.dart';

class TopIndicator extends StatelessWidget {
  const TopIndicator({super.key, required this.myProvider});

  final Data myProvider;

  @override
  Widget build(BuildContext context) {
    final int flaggedCellsCount = BoardUtils.countFlaggedCells(myProvider.board);
    final int minesCount = myProvider.minesCount;
    const double blockSize = 40;

    final Image flagIconBlock = Image(
      image: AssetImage('assets/skins/${myProvider.parameterSkin}_tile_flag.png'),
      fit: BoxFit.fill,
      height: blockSize,
      width: blockSize,
    );
    final Image mineIconBlock = Image(
      image: AssetImage('assets/skins/${myProvider.parameterSkin}_tile_mine.png'),
      fit: BoxFit.fill,
      height: blockSize,
      width: blockSize,
    );
    final Text markedMinesCountBlock = Text(
      flaggedCellsCount.toString(),
      style: TextStyle(
        fontSize: blockSize,
        fontWeight: FontWeight.bold,
        color: Theme.of(context).colorScheme.primary,
      ),
    );
    final Text placedMinesCountBlock = Text(
      minesCount.toString(),
      style: TextStyle(
        fontSize: blockSize,
        fontWeight: FontWeight.bold,
        color: Theme.of(context).colorScheme.primary,
      ),
    );

    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: [
        Row(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            markedMinesCountBlock,
            flagIconBlock,
            const SizedBox(width: blockSize * 2),
            mineIconBlock,
            placedMinesCountBlock,
          ],
        )
      ],
    );
  }
}
